@@ -1,13 +1,11 @@
 # Test scenario that correct API endpoints are hit when changing regions in credentials
 # Assumes testing with credentials which only has permissions to `aue` 
-
 test_that("STEP 1: AUE region returns data", {
   # Clear creds
   clear_all_credentials()
   reset_credentials()
-  
-  start_date <- "2025-06-30T00:00:00Z"
-  set_start_date(start_date)
+
+  set_start_date(Sys.getenv("start_date"))
   
   result <- get_forcedecks_data()
   expect_true(!is.null(result))
@@ -26,8 +24,7 @@ test_that("STEP 2: USE region FAILS", {
     region        = "use"
   )
   
-  start_date <- "2025-06-30T00:00:00Z"
-  set_start_date(start_date)
+  set_start_date(Sys.getenv("start_date"))
   
   expect_error(get_forcedecks_data(), "Forbidden \\(403\\): You do not have permission to access this resource.")
 })
@@ -45,8 +42,7 @@ test_that("STEP 3: EUW region FAILS", {
     region        = "euw"
   )
   
-  start_date <- "2025-06-30T00:00:00Z"
-  set_start_date(start_date)
+  set_start_date(Sys.getenv("start_date"))
   
   expect_error(get_forcedecks_data(), "Forbidden \\(403\\): You do not have permission to access this resource.")
 })
\ No newline at end of file
